// Config: parse triggers.yaml

// Copyright (C) 2021  Simon Ruderich
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

package config

import (
	"fmt"
	"os"
	"path/filepath"

	"gopkg.in/yaml.v2"

	"ruderich.org/simon/safcm"
)

func LoadTriggers(group string, files map[string]*safcm.File) error {
	path := filepath.Join(group, "triggers.yaml")

	var triggers map[string][]string
	x, err := os.ReadFile(path)
	if err != nil {
		if os.IsNotExist(err) {
			return nil
		}
		return err
	}
	err = yaml.UnmarshalStrict(x, &triggers)
	if err != nil {
		return fmt.Errorf("%s: failed to load: %v", path, err)
	}

	for p, x := range triggers {
		f, ok := files[p]
		if !ok {
			return fmt.Errorf("%s: %q does not exist in files/",
				path, p)
		}
		f.TriggerCommands = x
	}

	return nil
}
